Package: rextor
Title: Prepare 'WEXTOR' Data
Version: 1.1.0
Depends: R (>= 4.1.0)
Authors@R: c(person("Annika Tave", "Overlander", role = c("aut","cre"), email = "annika-tave.overlander@uni.kn",
             comment = c(ORCID = "0009-0006-8373-4086")),
            person("Ulf-Dietrich", "Reips", role = c("ths", "cph"), 
              comment = c(ORCID = "0000-0002-1566-4745")))
Description: Facilitate data preparation for data collected on 'WEXTOR' <https://wextor.eu>, created by Reips and Neuhaus (2002) <doi:10.3758/bf03195449>. Perform plausibility and other checks and make use of cool color palettes and themes for data visualization.
License: GPL (>= 3)
Date: 2026-05-06
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: dplyr, readr, ggplot2
Suggests: knitr, rmarkdown, rlang, scales, tibble
VignetteBuilder: knitr
URL: https://iscience-kn.github.io/rextor/
NeedsCompilation: no
Packaged: 2026-05-17 15:51:44 UTC; PCUser
Author: Annika Tave Overlander [aut, cre] (ORCID:
    <https://orcid.org/0009-0006-8373-4086>),
  Ulf-Dietrich Reips [ths, cph] (ORCID:
    <https://orcid.org/0000-0002-1566-4745>)
Maintainer: Annika Tave Overlander <annika-tave.overlander@uni.kn>
Repository: CRAN
Date/Publication: 2026-05-21 09:20:07 UTC
Built: R 4.6.0; ; 2026-05-22 00:23:21 UTC; unix

Package: rextor
Title: Prepare 'WEXTOR' Data
Version: 1.1.0
Depends: R (>= 4.1.0)
Authors@R: c(person("Annika Tave", "Overlander", role = c("aut","cre"), email = "annika-tave.overlander@uni.kn",
             comment = c(ORCID = "0009-0006-8373-4086")),
            person("Ulf-Dietrich", "Reips", role = c("ths", "cph"), 
              comment = c(ORCID = "0000-0002-1566-4745")))
Description: Facilitate data preparation for data collected on 'WEXTOR' <https://wextor.eu>, created by Reips and Neuhaus (2002) <doi:10.3758/bf03195449>. Perform plausibility and other checks and make use of cool color palettes and themes for data visualization.
License: GPL (>= 3)
Date: 2026-05-06
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: dplyr, readr, ggplot2
Suggests: knitr, rmarkdown, rlang, scales, tibble
VignetteBuilder: knitr
URL: https://iscience-kn.github.io/rextor/
NeedsCompilation: no
Packaged: 2026-05-17 15:51:44 UTC; PCUser
Author: Annika Tave Overlander [aut, cre] (ORCID:
    <https://orcid.org/0009-0006-8373-4086>),
  Ulf-Dietrich Reips [ths, cph] (ORCID:
    <https://orcid.org/0000-0002-1566-4745>)
Maintainer: Annika Tave Overlander <annika-tave.overlander@uni.kn>
Repository: CRAN
Date/Publication: 2026-05-21 09:20:07 UTC
Built: R 4.6.0; ; 2026-05-25 04:01:30 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(ggplot_add,dino_scale)
export(ask_rex)
export(check_ok)
export(getmode)
export(getperc)
export(informed_consent)
export(ip_check)
export(namepref)
export(namepref0)
export(path_to_file)
export(plausicheck)
export(read_WEXTOR)
export(removepref)
export(scale_rextor)
export(serious_check)
export(sess_length_check)
export(theme_wob)
import(dplyr)
import(ggplot2)
import(readr)
importFrom(stats,na.omit)
importFrom(stats,quantile)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# rextor <a href='https://iscience-kn.github.io/rextor/'><img src='man/figures/rextor_logo.png' align="right" /></a>

<!-- height="138" -->

rextor is an R package to facilitate data preparation for data collected
on WEXTOR. It offers functions to read in the data, help visualize the
data with color themes and scales that can help show data with a
light-on-dark color scheme, as well as a helper function. Here, the
dinosaur Rex will offer some words of wisdom and advice.

## Installation

You can install the development version of rextor from
[GitHub](https://github.com/) with:

``` r
# install.packages("devtools")
devtools::install_github("iscience-kn/rextor")
```

Or the official CRAN version via:

``` r
install.packages("rextor")
```

## Ask Rex 🦖

You can ask Rex for specific topics, such as t.tests and they will ask
you to specify the exact type of statistic you are looking for. If you
are generally having a hard time, just ask Rex for nothing in particular
and they will give you some encouragement to help you to try again!

``` r
library(rextor)

set.seed(1)
ask_rex()
#> 
#>                                      __
#>                                     / _)
#>                              .-^^^-/ /
#>                           __/       /
#>                           <__.|_|-|_|
#>                           
#>                           Small progress beats perfect code.
```

## Read in WEXTOR data

If you are not yet familiar with [WEXTOR](https://wextor.eu): It is an
online experiment building tool which relies on standards of web-based
experimentation and methodological best practices.

That means, generating studies to collect data is easy but analyzing
that data in R might be tricky. WEXTOR data comes in a specific
csv^comma-separated-values format and figuring out how to properly read
that data into R can be difficult to do when starting out your R
journey.

Luckily, with rextor, reading in that data becomes easy! We will use an
openly available data set on personality data collected in three
different conditions^For more information on the data, see
[github.com/iscience-kn/BiFiX](https://github.com/iscience-kn/BiFiX).
This dataset is also included in the rextor package in the
WEXTOR-exported format (without real IP addresses for data
anonymization). To read in this data from the package, you need to use
the `path_to_file()` function as shown below. Because some of the
automatically generated variable names are not ideal for usage in R, we
can also identify any variable name that starts with “.wx.” and have
those names start instead with “v\_” for “variable”. Another option is
to remove those prefixes altogether to be left with just easily legible
variable names, which we will do.

``` r
raw_data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"), 
                        keep_validation = FALSE)

# personality <- namepref(raw_data, ".wx.", "v_")
personality <- removepref(raw_data)
```

This way, the data frame *personality* is now nicely formatted with
useful variable names ready to be edited further. For example, we
recommend conducting dropout analysis as a routine part of analyzing
online data and offer the [dropR
package](https://iscience-kn.github.io/dropR/) to facilitate such
analyses!

#' Theme White on Black
#' 
#' This theme option is built to be used with a `ggplot2` plot.
#' It offers several options for a dark theme, i.e. dark background with light writing.
#'
#' @param max_font_size Maximum font size, used for the plot title (other font sizes are automatically
#'  adjusted accordingly).
#' @param contrast Character to indicate the choice of color palette depending on the desired contrast. 
#' Defaults to `"high"`. Should be one of `"max", "high", "medium", "low", "pink"` or `"rex"`.
#'
#' @import ggplot2
#'
#' @return Plot theme.
#' @export
#'
#' @examples
#' # Load the data
#' data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
#' 
#' # Create any plot
#' library(ggplot2)
#' ggplot(data, aes(age, color = gender, fill = gender)) + 
#'   geom_density(alpha = .5) + 
#'   theme_wob(contrast = "rex")
#' 
theme_wob <- function(max_font_size = 14,
                      contrast = "high"){
  
  dark <- switch(contrast,
                 "max" = "black",
                 "high" = "#191919",
                 "medium" = "#312D2A",
                 "low" = "#272D2D",
                 "pink" = "#210B2C",
                 "rex" = "#004000"
  )
  
  light <- switch(contrast,
                  "max" = "white",
                  "high" = "#FFF9E3",
                  "medium" = "#FAF3DD",
                  "low" = "#A1A6B4",
                  "pink" = "#FFCFCA",
                  "rex" = "#EAF2E3"
  )
  
  themewob <- theme(
    plot.background =  element_rect(fill = dark, color = dark),
    panel.background =  element_rect(fill = dark, color = dark),
    
    panel.grid = element_line(color = light),
    
    axis.text = element_text(color = light, size = max_font_size-4),
    axis.title = element_text(color = light, size = max_font_size-3),
    axis.line = element_line(color = light), 
    
    legend.background = element_rect(fill = dark),
    legend.text = element_text(color = light, size = max_font_size-4), 
    legend.title = element_text(color = light),
    
    plot.title = element_text(color = light, size = max_font_size),
    plot.subtitle = element_text(color = light, size = max_font_size-2),
    plot.caption = element_text(color = light, size = max_font_size-5)
    
  )
  
  return(themewob)
}

#' BiFiX - Big Five raw data
#'
#' Raw data from the BiFiX study (submitted for publication in BRM)
#'
#' @name BiFiX_data_raw
#' @format A data frame with 760 rows and 81 columns:
#' \describe{
#'   \item{$validation_var}{validation variable}
#'   \item{.wx.1.id}{ID}
#'   \item{.wx.3.experimental_condition}{Experimental condition}
#'   \item{big_...}{Big Five items (A - Agreeableness, C - Conscientiousness, 
#'    E - Extraversion, N - Neuroticism, O - Openness)}
#'   ...
#' }
#' @source <https://github.com/iscience-kn/BiFiX>
NULL

#' Read 'WEXTOR' Data
#' 
#' With this function, you can easily read in your 'WEXTOR' generated data.
#' By default, it will be exported as a "CSV" file, which stands for "comma-separated values". 
#' R has many available options of reading in this type of data, which can make it hard to navigate which one to use - especially for beginners.
#' 
#' In the [read_WEXTOR()] function, you just need to provide the `filepath`, i.e. the location of the CSV data file 
#' that you downloaded from 'WEXTOR'. 
#' If you want, you can already decided whether to keep the first column containing a so-called validation variable, but you don't have to.
#' With no other input, `rextor` will keep the variable for you. 
#' You can explicitly set `keep_validation` to FALSE if you like your data neat and do not need this extra measure.
#' The usage is explained in the examples down below using the open source BiFiX data with psychological Big Five personality traits.
#' 
#' This function prepares the 'WEXTOR' data so that it is readable by both R and you as a human.
#' It will give you your original data and also make the start and end time of each participation easier to read and work with later 
#' (by default, 'WEXTOR' will return these values as date and time separately, cluttering your dataset).
#'
#' @param filepath Location of the WEXTOR CSV file on your computer.
#' @param keep_validation Should the validation variable from WEXTOR be kept? TRUE by default.
#' 
#' @import dplyr
#' @import readr
#'
#' @return The WEXTOR data as an R data object.
#' @export
#'
#' @examples
#' 
#' data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
#' 
#' # If you don't need the validation variable, try
#' data_noval<-read_WEXTOR(path_to_file("BiFiX_data_raw.csv"),
#'                        keep_validation = FALSE)
#' 
read_WEXTOR <- function(filepath, 
                        keep_validation = TRUE){
  
  col_type_val <- if (keep_validation == TRUE) {
    col_logical()
  } else {
    col_skip()
  }
  
  # Resolve global variable issue
  .wx.4.start_time <- .wx.5.start_date <- .wx.6.end_time <- .wx.7.end_date <- NULL
  
  raw <- readr::read_delim(filepath, # filepath
                    delim = ";", trim_ws = TRUE,
                    col_types = cols(`$validation_var` = col_type_val,
                                     .wx.5.start_date = col_date(format = "%m/%d/%y"),
                                     .wx.7.end_date = col_date(format = "%m/%d/%y") # Dates should be brought into the right format
                                     )
                    ) |> 
    suppressMessages() # suppresses the "New names..." message which is not necessary
 
  
  prepped_data <- raw[, 1:(dim(raw)[2]-1)] |>  # skips the last col because it's empty
    dplyr::mutate(start_time = as.POSIXct(paste(.wx.5.start_date, .wx.4.start_time), format = "%Y-%m-%d %H:%M:%S"),
           end_time = as.POSIXct(paste(.wx.7.end_date, .wx.6.end_time), format = "%Y-%m-%d %H:%M:%S")) |>  # format date + time
    dplyr::select(-.wx.4.start_time, -.wx.5.start_date, -.wx.6.end_time, -.wx.7.end_date) |> 
    suppressMessages()
  
  return(prepped_data)
}

#' Ask Rex
#'
#' @description
#' This function lets you ask dino Rex for help. 
#' You can try to ask for specific functions and topics or just use the function as-is
#' for some motivational words of encouragement. :)
#' 
#' @param topic What you want to know about; either leave it blank for motivation or specify 'ttest', 'mean'... Input must be in quotes!
#'
#' @return Returns advice and explanations on R; sometimes Rex asks follow-up questions
#' 
#' @export
#'
#' @examples
#' # Get motivation
#' ask_rex()
#' 
#' # Get specific information
#' ask_rex("mean")
#' ask_rex(topic = "ttest")
#' 
ask_rex <- function(topic = "?"){
  
  if(topic %in% c("ttest", "tTest", "t-test")){
    ttype <- readline(prompt = "Please enter the number of the type of t-test you would like to know more about - (1) one-sample t-test,
(2) two-sample (independent) t-test or (3) paired (dependent) t-test.: ")
    
    reply <- switch (ttype,
      "1" = "t.test(x = variable, mu = fixed_mean) or check ?t.test for more help!",
      "2" = "t.test(means ~ group, var.equal = TRUE) or check ?t.test for more help!",
      "3" = "t.test(means ~ group, var.equal = TRUE, paired = TRUE) or check ?t.test for more help!",
      "Maybe ask something else?" # default
    )
    
  }
  else if (topic == "mean") {
    reply <- "mean(x) or if there are missing values in your data try mean(x, na.rm = TRUE)."
  } else if (topic %in% c("NA", "missing", "missings")){
    reply <- "is.na(x) returns TRUE where data is missing and FALSE where there is actual data."
  }
  else {
    reply <- sample(c("No worries, Rex got you!",
                      "You're doing great.",
                      "Trust the process!",
                      "Honestly, I don't know either.",
                      "If it runs, you're already winning.",
                      "Confused means you're learning.",
                      "Every error message is a hint, not an insult.",
                      "You don't need to understand everything - just the next step.",
                      "Small progress beats perfect code.",
                      "If it feels hard, you're doing it right.",
                      "Copy first, understand second, improve third.",
                      "One working line > ten perfect ideas.",
                      "Make it work, then make it nice.",
                      "If you can explain it, you can code it.",
                      "You can ask Rex about 'ttest', 'mean'...",
                      
                      cat("
                                     __
                                    / _)
                             .-^^^-/ /
                          __/       /
                          <__.|_|-|_|
                          
                          ")
                      
                      ), 1)
  }
  cat(reply)
}

#' Session Length Check
#' 
#' This function takes a dataframe as input as well as the minimum number of webpages in your web experiment or study,
#' that a participant should have seen in order to be considered a complete (or plausible) participation.
#' It flags the most extreme 10% of complete participations in the data as very slow or very fast.
#'
#' @param dataframe A dataframe containing WEXTOR data (needs to contain variables `page_trail` for the trail of 
#' webpages in the study and `session_length` for the overall time each participant spent on the study)
#' @param min_pages Numeric. The minimum number of pages a participant must have
#'   visited in the study for their participation to be considered plausible. Defaults to `6`.
#'
#' @returns A dataframe with added variables `sess_length_clean` for only completed session lengths, otherwise NA 
#'          and `check_sess_length` for a flag of the most extreme 10% of time needed to finish participation
#' @export
#' @importFrom stats quantile
#'
#' @examples
#' 
#' data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
#' new_data <- sess_length_check(data)
#' 
sess_length_check <- function(dataframe, min_pages = 6){
  if(any(grepl(".wx.", names(dataframe)))){
    new <- removepref(dataframe)
  } else {
    new <- dataframe
  }
  
  new$true_trail <- strsplit(new$page_trail, " - ") |>  lengths()
  new$check_page <- ifelse(new$true_trail >= min_pages, "ok", "incomplete")

  new$sess_length_clean <- ifelse(new$check_page == "incomplete", NA, new$session_length)
  new$check_sess_length <- ifelse(new$sess_length_clean < quantile(new$sess_length_clean, 0.05, na.rm = T),
                                     "very fast",
                                     ifelse(new$sess_length_clean > quantile(new$sess_length_clean, 0.95, na.rm = T),
                                            "very slow",
                                            "ok")
                                    )
    
    return(new)
  # }

  # # old version
  # new2 <- dataframe |>
  #   dplyr::mutate(
  #     sess_length_clean = ifelse(check_page == "incomplete", NA, session_length)
  #   )
  # 
  # new2$check_sess_length <- ifelse(between(new2$sess_length_clean, 
  #                                          quantile(new2$sess_length_clean, 0.05, na.rm = T), 
  #                                          quantile(new2$sess_length_clean, 0.95, na.rm = T)),
  #                             "ok", "very slow or fast")
  #
  # return(new2)
}



#' Check for duplicate IP addresses
#'
#' `ip_check()` identifies potential duplicate participations in a dataset
#' by checking for repeated IP addresses. Cases with duplicated IPs are
#' flagged as `"possible duplicate"`, while unique IPs are labeled `"ok"`.
#' Keep in mind that in some cases, duplicate IP addresses should not lead to exclusion,
#' for example when different participants (such as siblings or flatmates) plausibly
#' use the same device.
#'
#' If WEXTOR-style prefixes (i.e. `.wx.`) are detected in the variable names,
#' they are removed prior to performing the check.
#'
#' @param dataframe A data frame containing the study data. Must include a
#'   variable named `ip` representing participants' IP addresses.
#'
#' @returns A data frame with an additional column `check_ip`, indicating
#'   whether each case has a unique IP (`"ok"`) or is a potential duplicate
#'   (`"possible duplicate"`).
#'
#' @details The function uses `duplicated()` to flag repeated IP addresses.
#'   Only subsequent occurrences are marked as duplicates; the first instance
#'   of each IP is treated as valid.
#' @export
#'
#' @examples
#' data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
#' # The example data does not contain real IPs (data protection), so we will use simulate ones
#' data$ip <- sample(1:1000, nrow(data), replace = TRUE)
#' 
#' new_data <- ip_check(data)
#' 
ip_check <- function(dataframe){

  if(any(grepl(".wx.", names(dataframe)))){
    new3 <- removepref(dataframe)
  } else {
    new3 <- dataframe
  }
  
  new3$check_ip <- ifelse(duplicated(new3$ip), "possible duplicate", "ok")
  return(new3)
}



#' Plausibility check on WEXTOR study data
#'
#' `plausicheck()` performs basic plausibility checks on a study dataset to
#' identify potentially invalid or suspicious participation. The function can
#' check whether participants visited a minimum number of pages, whether the
#' recorded session length appears plausible, and whether IP addresses indicate
#' duplicate participation.
#'
#' If WEXTOR prefixes are detected in the variable names, they are removed before
#' the plausibility checks are applied.
#'
#' @param dataframe A data frame containing the study data (needs to contain variables `page_trail` for the trail of 
#' webpages in the study & `session_length` for the overall time each participant spent on the study (if
#' session length is to be checked) and `ip` for participants' IP addresses (if IP is to be checked)).
#' @param min_pages Numeric. The minimum number of pages a participant must have
#'   visited  in the study for their participation to be considered plausible.
#' @param check_sess_length Logical. Should the session length plausibility check
#'   be performed? Defaults to `TRUE`.
#' @param check_ip Logical. Should the IP address plausibility check be performed?
#'   Defaults to `TRUE`.
#'
#' @returns A data frame with additional plausibility check variables. The final
#'   variable `check_plausibility` indicates whether all selected checks were passed
#'   (`"all ok"`) or whether the case should be excluded (`"exclude"`). Keep in mind
#'   that researchers are advised to make sure that the `"exclude"`-cases were correctly 
#'   identified and are indeed of poorer data quality to avoi unnecessary data loss.
#' @export
#'
#' @examples
#' 
#' data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
#' # The example data does not contain real IPs (data protection), so we will use simulate ones
#' data$ip <- sample(1:1000, nrow(data), replace = TRUE)
#' 
#' plausi_data <- plausicheck(dataframe = data,
#'   min_pages = 6,
#'   check_sess_length = TRUE,
#'   check_ip = TRUE)
#' 
plausicheck <- function(dataframe,
                        min_pages,
                        check_sess_length = TRUE,
                        check_ip = TRUE){
  # If no Plausicheck is selected, exit and select at least one
  if(!any(c(check_sess_length, check_ip))){
    stop("Please select at least one plausibility check to be performed! 
You can choose `sess_length_check` and `ip_check`.")
  } else{
    if(any(grepl(".wx.", names(dataframe)))){
      plausi <- removepref(dataframe)
    } else {
      plausi <- dataframe
    }
    
    if(is.null(min_pages)){
      warning("Please define the minimum number of pages that a participant of your study should have visited for a plausible participation, the default is 6.")
    } else if(check_sess_length){
      plausi <- sess_length_check(plausi, min_pages)
    }
    
    if(check_ip){
      plausi <- ip_check(plausi)
    }
    
    plausi$check_plausibility <- ifelse(check_ok(plausi, "check_page") &
                                          check_ok(plausi, "check_sess_length") &
                                          check_ok(plausi, "check_ip"),
                                        "all ok",
                                        "exclude"
                                        )
    
  return(plausi)
  }
}

#' Filter data frame by seriousness check
#'
#' Filter your data frame by your item for the "seriousness check". 
#' If the data comes from 'WEXTOR' with no previous changes to the automatically created variable,
#' you will be able to accept all defaults in this function and simply input the data frame.
#'
#' @param dataframe Data which contains a variable for the seriousness check.
#' @param varname Variable for the seriousness check. Defaults to `"seriousness"`.
#' @param keep Values from the variable to keep. Defaults to `"participate"`
#'
#' @return Filtered data
#' @export
#'
#' @examples
#' data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
#' serious_only <- serious_check(data)
#' 
serious_check <- function(dataframe, varname = "seriousness", keep = "participate"){
  new <- subset(dataframe, eval(parse(text = varname)) == keep)
  return(new)
}

#' Informed Consent Filter
#' 
#' One of the best practices in data collection is including and informed consent question.
#' With this function you can automatically filter out rows where participants did not explicitly consent to their data being used.
#'
#' @param dataframe A dataframe of data collected with 'WEXTOR'
#' @param varname character. Variable name of informed consent variable. Defaults to "informedconsent".
#' 
#' @importFrom stats na.omit
#'
#' @returns Returns data with cases filtered out that did not check the informed consent box
#' @export
#' @examples
#' 
#' data <- data.frame(informedconsent = c("checked", "not checked", "checked"))
#' informed_only <- informed_consent(data) 
#' 
informed_consent <- function(dataframe, varname = "informedconsent"){
  
  new <- dataframe[dataframe[varname] == "checked", ] |> na.omit()
  new
}

#' Remove 'WEXTOR' variable name prefixes (automatic)
#'
#' This function strips the old prefix from the server variable names of the dataframe.
#' It identifies such variables that start with ".wx.#." where # stands for any number, or simply ".wx." and then removes
#' these prefixes for more easily legible and usable variable names in your data!
#'
#' @param dataframe A dataframe, usefully containing variables that have the server prefix ".wx.#."
#'
#' @returns  Returns dataframe with those variables renamed that start with the old prefix.
#' @export
#'
#' @examples
#' bli <- tibble::tibble(.wx.1.ar = 1:5, y_ar = 6:10, .wx.z = 11:15)
#' blu <- removepref(bli)
#' names(bli)
#' names(blu)
#' 
removepref <- function(dataframe){
  value <- stripped <- new_names <- NULL
  
  pref_old <- ".wx.\\d+."
  
  # dataframe must be a dataframe
  namedf <- data.frame(value = names(dataframe))
  namedf$stripped <- ifelse(grepl(pref_old, namedf$value),
                            substr(namedf$value, 7, nchar(namedf$value)),
                            namedf$value)
  namedf$new_names <- ifelse(startsWith(namedf$stripped, ".wx."),
                             substr(namedf$stripped, 5, nchar(namedf$stripped)),
                             namedf$stripped)
  
  names(dataframe) <- namedf$new_names
  
  
  
  # namedf <- tibble::as_tibble(names(dataframe))  |>
  #   dplyr::mutate(stripped = ifelse(grepl(pref_old, value),
  #                                   substr(value, 7, nchar(value)),
  #                                   value), 
  #                 new_names = ifelse(startsWith(stripped, ".wx."),
  #                                    substr(stripped, 5, nchar(stripped)),
  #                                    stripped)
  #   )
  # 
  # names(dataframe) <- namedf |> dplyr::pull(new_names)
  return(dataframe)
}

#' Coloring Scale for Data Visualization
#' 
#' This scale is very versatile and powerful. It offers several color palettes to choose from and automatically recognizes whether to use
#' a discrete or continuous scale depending on the data type of the mapping object.
#' It can also be used for both `color` and `fill` aesthetics by defining `aesthetic` accordingly directly inside the function!
#'
#' @param pal Color palette. Use either numbers from 1 to X or one of the names: `'arby'`, `'cute'`...
#' @param direction Direction of the color palette. Keep blank or use 1 for the default direction or use -1 to reverse the colors.
#' @param aesthetic Which aesthetic to use the scale on; either `color` or `fill`, defaults to `color`.
#' @param ... Other common scale parameters.
#'
#' @import ggplot2
#' @return `ggplot` plot object
#' 
#' @export
#'
#' @examples
#' library(ggplot2)
#' ggplot(iris, aes(Species, Petal.Width, color = Petal.Width)) + 
#' geom_jitter() + 
#' theme_wob() + 
#' scale_rextor()
#' 
#' data <- data.frame(Time = rep(c("Time 1", "Time 2", "Time 3", "Time 4", 
#'                                 "Time 5", "Time 6", "Time 7", "Time 8"), 
#'                                 each = 2),
#'                                 cont = 1:16,
#'                                 Value = c(8, 5, 10, 3, 8, 5, 10, 3,  8, 5, 10, 3,  8, 5, 10, 3))
#' 
#' ggplot(data, aes(x = Time, y = Value, color = Time, fill = Time)) +
#'   geom_boxplot(alpha = 0.95) +
#'     theme_wob() +
#'     scale_rextor(pal = "neon") +
#'     scale_rextor(pal = "neon", aesthetic = "fill")
#'     
#' ggplot(data, aes(x = cont, y = Value, color = cont, fill = cont)) +
#'   geom_jitter(alpha = 0.8, size = 8) +
#'   theme_minimal() +
#'   scale_rextor(pal = "wextor") +
#'   scale_rextor(pal = "wextor", aesthetic = "fill")
#' 
scale_rextor <- function(pal =  "cute",
                            direction = 1,
                            aesthetic = "color",
                            ...) {
  
  structure(list(pal = pal, direction = direction,
                 aesthetic = aesthetic,
                 ...), class = "dino_scale")
}

#' @export
#' @method ggplot_add dino_scale
ggplot_add.dino_scale <- function(object, plot, object_name, ...){
  # Definition of the ggplot_add.dino_scale method
  # Set arguments
  args <- object
  pal <- args$pal
  direction <- args$direction
  aesthetic <- ifelse(args$aesthetic == "fill", "fill", "colour")

  # Define rextor custom color scales
  paletteses <- list(
    arby = c("#FC4A2B", "#FE9116", "#FFD700", "#3CB371", "#4682B4", "#5F3BA5", "#4B0082"), 
    cute = c("#BF7389", "#F2D0A9", "#D79B86", "#99C1B9", "#E87478"),
    wextor = c("#326699", "#53D8FB", "#66C3FF", "#254CA7", "#B79FAD", "#B3424F", "#901137", "#7F0000"), 
    dualtone = c("#870058",  "#E65F5C", "#c8d6af", "#104547","#c97f54", "#ed1c24"),
    colorful = c("#750400", "#f7ad00", "#58015e", "#0006b8", "#00d9ce", "#16ab31", "#eb6eb7", "#d16c00"), 
    protanomaly = c("#6E2c4d", "#cd8b5c", "#ccae88", "#cad1b3", "#193346", "#c66123"), 
    forest = c("#6C464F", "#475B52", "#226F54", "#87C38F","#656839", "#F4F0BB", "#9C8D6D", "#43291F"), 
    hadestown = c("#d26c01", "#cfa362", "#991400", "#fd3122", "#C1B397", "#654F3C", "#85604D", "#dbc191"), 
    neon = c("#FFBB00", "#98CE00", "#16E0BD", "#0006b8", "#8B08A0",  "#D11150", "#F72C25", "#FF7100")
  )
  
  # Reverse palette for direction = -1
  if(direction == 1){
    chosen_pal <- paletteses[[pal]]
  } else if (direction == -1){
    chosen_pal <- rev(paletteses[[pal]])
  } else {
    stop("Direction must be either 1 or -1 to reverse the palette.")
  }
  
  # Find the first layer with the defined 'color' aesthetic
  # If ggplot includes aesthetics within geom_* this will recognize the class of the argument based on what is inside it
  for (i in seq_along(plot$layers)) {
    if (aesthetic %in% names(plot$layers[[i]]$mapping)) {
      if(aesthetic %in% "colour"){
        color_var <- plot$layers[[i]]$mapping$colour
      } else {
        color_var <- plot$layers[[i]]$mapping$fill
      }
      
      # var_evaluated <- rlang::eval_tidy(color_var, plot$layers[[i]]$data)
      var_evaluated <- rlang::eval_tidy(color_var, plot$data)
      break
    } else {
      color_var <- NULL
    }
  }
  
  
  # If 'color_var' was not found in any layer, check in the base ggplot call
  if (is.null(color_var)) {
    # Depending on the selected aesthetic, color var is defined as color/
    if(aesthetic == "colour"){
      color_var <- plot$mapping$colour
    } else {
      color_var <-  plot$mapping$fill
    }
    
    var_evaluated <- rlang::eval_tidy(color_var, plot$data)
  }

  # If 'color_var' is not yet found, returns error
  if (is.null(color_var)) {
    stop(paste0("No '", aesthetic, "' color defined, please define '", aesthetic,  "' in your plot aesthetics."))
    # return(plot) # could also just return the plot naked...?
  }
  
  # Evaluates whether the variable is numeric and continuous
  # Discrete:
  if(!is.numeric(var_evaluated) | unique(var_evaluated) |> length() < 10){
    
    scale <- discrete_scale(
      aesthetics = object$aesthetic,
      palette = function(n) chosen_pal[1:n],
      ...
    )
    

  } else {
    
    # Define continuous scale
    scale <- ggplot2::continuous_scale(
      aesthetics = aesthetic,
      palette = scales::gradient_n_pal(chosen_pal),
      ...
    )

  }
  
  newplot <- plot + scale
  return(newplot)
  
  
}

#' Add variable name prefix (with substitution)
#'
#' This function strips the old prefix from the variable names of the dataframe.
#' It then adds the new prefix where the old one was and changes the dataframe's names to the new ones.
#'
#' @param dataframe A dataframe
#' @param pref_old Old prefix character that some or all variables in the dataframe have
#' @param pref_new New prefix character to replace the old one
#'
#' @return Returns dataframe with those variables renamed that start with the old prefix.
#' @export
#'
#' @examples
#' bla <- tibble::tibble(x_ar = 1:5, y_ar = 6:10)
#' blo <- namepref(bla, "x_", "z_")
#' names(bla)
#' names(blo)
#'
namepref <- function(dataframe, pref_old, pref_new){
  value <- stripped <- new_names <- NULL
  
  namedf <- data.frame(value = names(dataframe))
  namedf$stripped <- ifelse(startsWith(namedf$value, pref_old), 
                            substr(namedf$value, (nchar(pref_old)+1), nchar(namedf$value)), 
                            namedf$value)
  namedf$new_names <- ifelse(startsWith(namedf$value, pref_old), 
                            paste0(pref_new, namedf$stripped), 
                            namedf$value)
  
  names(dataframe) <- namedf$new_names
  
 # pref_old and pref_new must be character strings, dataframe must be a dataframe
  # namedf <- tibble::as_tibble(names(dataframe))  |>
  #   dplyr::mutate(stripped = ifelse(startsWith(value, pref_old), 
  #                                   substr(value, (nchar(pref_old)+1), nchar(value)), 
  #                                   value),
  #                 new_names = ifelse(startsWith(value, pref_old), 
  #                                    paste0(pref_new, stripped), 
  #                                    value))
  # 
  # names(dataframe) <- namedf |> dplyr::pull(new_names)
  return(dataframe)
}


#' Add variable name prefix (without substitution)
#'
#' This function adds the new prefix and changes the dataframe's names to the new ones.
#'
#' @param dataframe A dataframe
#' @param pref_new New prefix character to add to all variable namess in the dataframe have
#'
#' @return Returns dataframe with all variables renamed to start with the new prefix.
#' @export
#'
#' @examples
#' bla <- tibble::tibble(x_ar = 1:5, y_ar = 6:10)
#' blo <- namepref0(bla, "var")
#' names(bla)
#' names(blo)
#'
namepref0 <- function(dataframe, pref_new){
  value <- new_names <- NULL
  
  # pref_new must be a character string, dataframe must be a dataframe
  namedf <- data.frame(value = names(dataframe))
  
  namedf$new_names <- paste0(pref_new, namedf$value)
  
  names(dataframe) <- namedf$new_names
  
  return(dataframe)
}

#' Get the mode of a vector or variable
#'
#' The mode is the number that appears the most often in a vector or variable.
#' This measure is especially important for nominal variables since the mean 
#' or median cannot meaningfully be reported.
#'
#' @param v a vector of variable in dataframe
#'
#' @return Returns the mode of v, i.e., the value occurring most often
#' @export
#'
#' @examples
#' 
#' vec <- c("A", "A", "B")
#' getmode(vec)
#' 
getmode <- function(v) {
  uniqv <- unique(v)
  uniqv[which.max(tabulate(match(v, uniqv)))]
}

#' Get percentage of a value
#'
#' @param data A dataframe 
#' @param var A variable in the dataframe, written as a character in quotes, e.g. "var"
#' @param val A value of variable var of which to get the percentage, also in quotes
#'
#' @return Returns the percentage of value `val` in relation to all values of `var`
#' @export
#'
#' @examples
#'  getperc(data.frame(a = c("duck", "duck", "goose")),
#'   "a", 
#'   "duck")
#'  
#'  # Also works when val is indexed (alphabetically)
#'  getperc(data.frame(a = c("duck", "duck", "goose")),
#'   "a", 
#'   2)
#' 
getperc <- function(data, var, val){
  # data must be a dataframe, var must be a variable in this data fram. GOTCHA: var must be written in "" , e.g. "var".
  # Val must be a value in var
  
  n_data <- dim(data)[1]
  
  round(((table(data[var])/n_data)[[val]])*100, 2) # %>% round(2)
}

#' Get file path to example data file
#'
#' This function makes the example data from the BiFiX study (submitted for publication in BRM) easy to access.
#'
#' @param path Name of file in quotes with extension;
#' `"BiFiX_data_raw.csv"` will work.
#' If `NULL`, the example file will be listed.
#' 
#' @return Gives the path to the example file included in the package. Meant for use in `read_WEXTOR()`.
#' @export
#' @examples
#' path_to_file()
#' path_to_file("BiFiX_data_raw.csv")
#' head(read.csv(path_to_file("BiFiX_data_raw.csv")))
#' @source This function is adapted from `palmerpenguins` (which is adapted from `readxl::readxl_example()`).
path_to_file <- function(path = NULL) {
  if (is.null(path)) {
    dir(system.file("extdata", package = "rextor"))
  } else {
    system.file("extdata", path, package = "rextor", mustWork = TRUE)
  }
}


#' Check whether a plausibility condition is satisfied
#'
#' Returns a logical vector indicating whether a given check column equals `"ok"`.
#' If the column does not exist in the data, all cases are treated as passing.
#' 
#' Used inside the `plausicheck()` function.
#'
#' @param data A data frame containing plausibility check variables.
#' @param col A character string specifying the column name to check for "ok" entries (case-sensitive).
#'
#' @returns A logical vector of length `nrow(data)`.
#'
#' @export
#'
#' @examples
#' example_df <- data.frame(check_ip = c("ok", "nope", "ok", "OK"))
#' check_ok(example_df, "check_ip")
check_ok <- function(data, col) {
  if (col %in% names(data)) {
    data[[col]] == "ok"
  } else {
    rep(TRUE, nrow(data))
  }
}

---
title: "Big Five Example - BiFiX"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Big Five Example - BiFiX}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
# build_rmd("vignettes/big-five-example.Rmd")

library(rextor)
```

<!-- # ```{r setup} -->
<!-- # library(rextor) -->
<!-- # ``` -->

In this vignette, you will get a complete Walkthrough of how to use `rextor` for your own data analysis.
We will use Open Source data on Big Five personality traits, available from the iScience Konstanz account on GitHub: [https://github.com/iscience-kn/BiFiX](https://github.com/iscience-kn/BiFiX).

## Step 1: Reading in the Data

We will be reading in the data directly from the iScience GitHub Account. 
Make sure to select the raw data file on GitHub or just copy the code below.

In this dataset, we do not need the validation variable.
It facilitates dropout analysis in some cases (especially in one-item-one-screen designs) but here we will focus on other variables to clean the data[^dc]. 
In the first step, we will read in the WEXTOR based data and assign in to a variable named "raw", that will become our data frame.

[^dc]: Data cleaning can be a misleading term: It has nothing to do with removing data we might not like because it does not fit our hypothesis. However, there are some good indicators that e.g. someone did not answer truthfully, did not read properly and overall did not provide data with good quality. Those cases should be excluded from further analyses because they could lead to false results.

```{r read-in}
raw <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"),
                    keep_validation = FALSE)

```

## Step 2: Data Cleaning

Great! 
We now have our empirical data in R, ready to be worked with.
But there are some things which are not yet ideal, so will use some more `rextor` functions to make our lives easier.

When you open up the data and look at it, you might notice that the first variables in the data, which are automatically recorded server variables have the prefix ".wx.".
In R, we generally want our variable names to start with a letter for easy access, so we can either use the `namepref` function (for variable **name pref**ix) to change that to "v_".
Notice that this function will not add that prefix to the variables that were deliberately named by someone in WEXTOR.
Another option is to remove server-generated variable prefixes altogether, which is the option we will choose here.
It will only change those variable names that actually have the old prefix that you specify as shown.

```{r}
data <- removepref(raw) # namepref(raw, ".wx.", "v_")
```

### Seriousness check

We will also perform a "seriousness check" and filter out data of anyone who did not confirm they want to participate seriously.
This has proven to improve data quality.

CAVE: With this step you will remove likely remove a lot of your data so make sure you always have a safety copy of the original data.
I recommend keeping the _raw_ dataset in your R environment while you prepare your data so you can go back and repeat or adjust any step whenever necessary. 
That way you can also look at every row of data in your raw data that was removed in later steps and manually check if that filtering was correct or if you need to add some of the data back in.

```{r}
data2 <- serious_check(data)
```

### Plausibility check

Similar to the seriousness check, **plausibility checks are essential** in online studies to ensure data quality because researchers have less control over participants’ environments and behavior than in lab settings. 
Responses may include inattentive participants, bots, or repeated submissions, all of which can bias results if left unchecked. 
Two particularly effective starting points are **session length** and **IP-based duplicate checks**. 
Extremely short or long session durations can indicate careless responding or technical issues, while repeated IP addresses may signal multiple submissions from the same source. 
Together, these checks provide a quick, low-threshold way to flag clearly problematic cases before applying more fine-grained data screening procedures.
With `rextor`, the checks described above can be performed separately (as shown below in the commented out part) or in one meta-function.
Possibly implausible cases will be flagged as such so the researcher can make an informed decision on whether to keep these cases or exclude them for better data quality.
As the `BiFiX` dataset does not include real IP adresses for data security reasons, we will add simulated ones to show the functionality of the IP check:

```{r}
# Add random numbers to act as simulated IP addresses
data2$ip <- sample(1:1000, nrow(data2), replace = TRUE)

# Perform separate checks
# data3 <- sess_length_check(data2, 
#                      min_pages = 6)
# data3 <- ip_check(data3)

# Perform overall plausibility check
data3 <- plausicheck(data2, 
                     min_pages = 6,
                     check_sess_length = TRUE,
                     check_ip = TRUE)
```


## Pipe it all together

When preparing data for further analyses it makes sense to have an unchanged raw version of the data in R and then save any changes in a new data frame.
However, in order to avoid situations like above with `data1`, `data2` etc., you might want to use pipes to perform several data preparation steps in one go.
Since version 4.1.0, R offers a native pipe that looks like this: `|>`.
It allows you to take the output from previous functions as the first input of the next function and thus create a workflow pipeline that is easily adjustable and usually very efficient and clear to read.
To avoid having to add simulated IPs here again, we will skip this check but still perform the meta function `plausicheck` to get the overall plausibilty variable added to the data.

```{r}
final_data <- raw |> 
  removepref() |> 
  serious_check() |> 
  plausicheck(min_pages = 6, check_sess_length = TRUE, check_ip = FALSE)
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plausi_checks.R
\name{plausicheck}
\alias{plausicheck}
\title{Plausibility check on WEXTOR study data}
\usage{
plausicheck(dataframe, min_pages, check_sess_length = TRUE, check_ip = TRUE)
}
\arguments{
\item{dataframe}{A data frame containing the study data (needs to contain variables \code{page_trail} for the trail of
webpages in the study & \code{session_length} for the overall time each participant spent on the study (if
session length is to be checked) and \code{ip} for participants' IP addresses (if IP is to be checked)).}

\item{min_pages}{Numeric. The minimum number of pages a participant must have
visited  in the study for their participation to be considered plausible.}

\item{check_sess_length}{Logical. Should the session length plausibility check
be performed? Defaults to \code{TRUE}.}

\item{check_ip}{Logical. Should the IP address plausibility check be performed?
Defaults to \code{TRUE}.}
}
\value{
A data frame with additional plausibility check variables. The final
variable \code{check_plausibility} indicates whether all selected checks were passed
(\code{"all ok"}) or whether the case should be excluded (\code{"exclude"}). Keep in mind
that researchers are advised to make sure that the \code{"exclude"}-cases were correctly
identified and are indeed of poorer data quality to avoi unnecessary data loss.
}
\description{
\code{plausicheck()} performs basic plausibility checks on a study dataset to
identify potentially invalid or suspicious participation. The function can
check whether participants visited a minimum number of pages, whether the
recorded session length appears plausible, and whether IP addresses indicate
duplicate participation.
}
\details{
If WEXTOR prefixes are detected in the variable names, they are removed before
the plausibility checks are applied.
}
\examples{

data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
# The example data does not contain real IPs (data protection), so we will use simulate ones
data$ip <- sample(1:1000, nrow(data), replace = TRUE)

plausi_data <- plausicheck(dataframe = data,
  min_pages = 6,
  check_sess_length = TRUE,
  check_ip = TRUE)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/serious_check.R
\name{serious_check}
\alias{serious_check}
\title{Filter data frame by seriousness check}
\usage{
serious_check(dataframe, varname = "seriousness", keep = "participate")
}
\arguments{
\item{dataframe}{Data which contains a variable for the seriousness check.}

\item{varname}{Variable for the seriousness check. Defaults to \code{"seriousness"}.}

\item{keep}{Values from the variable to keep. Defaults to \code{"participate"}}
}
\value{
Filtered data
}
\description{
Filter your data frame by your item for the "seriousness check".
If the data comes from 'WEXTOR' with no previous changes to the automatically created variable,
you will be able to accept all defaults in this function and simply input the data frame.
}
\examples{
data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
serious_only <- serious_check(data)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BiFiX_data_raw.R
\name{BiFiX_data_raw}
\alias{BiFiX_data_raw}
\title{BiFiX - Big Five raw data}
\format{
A data frame with 760 rows and 81 columns:
\describe{
\item{$validation_var}{validation variable}
\item{.wx.1.id}{ID}
\item{.wx.3.experimental_condition}{Experimental condition}
\item{big_...}{Big Five items (A - Agreeableness, C - Conscientiousness,
E - Extraversion, N - Neuroticism, O - Openness)}
...
}
}
\source{
\url{https://github.com/iscience-kn/BiFiX}
}
\description{
Raw data from the BiFiX study (submitted for publication in BRM)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utility.R
\name{getperc}
\alias{getperc}
\title{Get percentage of a value}
\usage{
getperc(data, var, val)
}
\arguments{
\item{data}{A dataframe}

\item{var}{A variable in the dataframe, written as a character in quotes, e.g. "var"}

\item{val}{A value of variable var of which to get the percentage, also in quotes}
}
\value{
Returns the percentage of value \code{val} in relation to all values of \code{var}
}
\description{
Get percentage of a value
}
\examples{
 getperc(data.frame(a = c("duck", "duck", "goose")),
  "a", 
  "duck")
 
 # Also works when val is indexed (alphabetically)
 getperc(data.frame(a = c("duck", "duck", "goose")),
  "a", 
  2)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utility.R
\name{getmode}
\alias{getmode}
\title{Get the mode of a vector or variable}
\usage{
getmode(v)
}
\arguments{
\item{v}{a vector of variable in dataframe}
}
\value{
Returns the mode of v, i.e., the value occurring most often
}
\description{
The mode is the number that appears the most often in a vector or variable.
This measure is especially important for nominal variables since the mean
or median cannot meaningfully be reported.
}
\examples{

vec <- c("A", "A", "B")
getmode(vec)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/namepref.R
\name{namepref}
\alias{namepref}
\title{Add variable name prefix (with substitution)}
\usage{
namepref(dataframe, pref_old, pref_new)
}
\arguments{
\item{dataframe}{A dataframe}

\item{pref_old}{Old prefix character that some or all variables in the dataframe have}

\item{pref_new}{New prefix character to replace the old one}
}
\value{
Returns dataframe with those variables renamed that start with the old prefix.
}
\description{
This function strips the old prefix from the variable names of the dataframe.
It then adds the new prefix where the old one was and changes the dataframe's names to the new ones.
}
\examples{
bla <- tibble::tibble(x_ar = 1:5, y_ar = 6:10)
blo <- namepref(bla, "x_", "z_")
names(bla)
names(blo)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plausi_checks.R
\name{ip_check}
\alias{ip_check}
\title{Check for duplicate IP addresses}
\usage{
ip_check(dataframe)
}
\arguments{
\item{dataframe}{A data frame containing the study data. Must include a
variable named \code{ip} representing participants' IP addresses.}
}
\value{
A data frame with an additional column \code{check_ip}, indicating
whether each case has a unique IP (\code{"ok"}) or is a potential duplicate
(\code{"possible duplicate"}).
}
\description{
\code{ip_check()} identifies potential duplicate participations in a dataset
by checking for repeated IP addresses. Cases with duplicated IPs are
flagged as \code{"possible duplicate"}, while unique IPs are labeled \code{"ok"}.
Keep in mind that in some cases, duplicate IP addresses should not lead to exclusion,
for example when different participants (such as siblings or flatmates) plausibly
use the same device.
}
\details{
If WEXTOR-style prefixes (i.e. \code{.wx.}) are detected in the variable names,
they are removed prior to performing the check.

The function uses \code{duplicated()} to flag repeated IP addresses.
Only subsequent occurrences are marked as duplicates; the first instance
of each IP is treated as valid.
}
\examples{
data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
# The example data does not contain real IPs (data protection), so we will use simulate ones
data$ip <- sample(1:1000, nrow(data), replace = TRUE)

new_data <- ip_check(data)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plausi_checks.R
\name{sess_length_check}
\alias{sess_length_check}
\title{Session Length Check}
\usage{
sess_length_check(dataframe, min_pages = 6)
}
\arguments{
\item{dataframe}{A dataframe containing WEXTOR data (needs to contain variables \code{page_trail} for the trail of
webpages in the study and \code{session_length} for the overall time each participant spent on the study)}

\item{min_pages}{Numeric. The minimum number of pages a participant must have
visited in the study for their participation to be considered plausible. Defaults to \code{6}.}
}
\value{
A dataframe with added variables \code{sess_length_clean} for only completed session lengths, otherwise NA
and \code{check_sess_length} for a flag of the most extreme 10\% of time needed to finish participation
}
\description{
This function takes a dataframe as input as well as the minimum number of webpages in your web experiment or study,
that a participant should have seen in order to be considered a complete (or plausible) participation.
It flags the most extreme 10\% of complete participations in the data as very slow or very fast.
}
\examples{

data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
new_data <- sess_length_check(data)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/informed_consent.R
\name{informed_consent}
\alias{informed_consent}
\title{Informed Consent Filter}
\usage{
informed_consent(dataframe, varname = "informedconsent")
}
\arguments{
\item{dataframe}{A dataframe of data collected with 'WEXTOR'}

\item{varname}{character. Variable name of informed consent variable. Defaults to "informedconsent".}
}
\value{
Returns data with cases filtered out that did not check the informed consent box
}
\description{
One of the best practices in data collection is including and informed consent question.
With this function you can automatically filter out rows where participants did not explicitly consent to their data being used.
}
\examples{

data <- data.frame(informedconsent = c("checked", "not checked", "checked"))
informed_only <- informed_consent(data) 

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_WEXTOR.R
\name{read_WEXTOR}
\alias{read_WEXTOR}
\title{Read 'WEXTOR' Data}
\usage{
read_WEXTOR(filepath, keep_validation = TRUE)
}
\arguments{
\item{filepath}{Location of the WEXTOR CSV file on your computer.}

\item{keep_validation}{Should the validation variable from WEXTOR be kept? TRUE by default.}
}
\value{
The WEXTOR data as an R data object.
}
\description{
With this function, you can easily read in your 'WEXTOR' generated data.
By default, it will be exported as a "CSV" file, which stands for "comma-separated values".
R has many available options of reading in this type of data, which can make it hard to navigate which one to use - especially for beginners.
}
\details{
In the \code{\link[=read_WEXTOR]{read_WEXTOR()}} function, you just need to provide the \code{filepath}, i.e. the location of the CSV data file
that you downloaded from 'WEXTOR'.
If you want, you can already decided whether to keep the first column containing a so-called validation variable, but you don't have to.
With no other input, \code{rextor} will keep the variable for you.
You can explicitly set \code{keep_validation} to FALSE if you like your data neat and do not need this extra measure.
The usage is explained in the examples down below using the open source BiFiX data with psychological Big Five personality traits.

This function prepares the 'WEXTOR' data so that it is readable by both R and you as a human.
It will give you your original data and also make the start and end time of each participation easier to read and work with later
(by default, 'WEXTOR' will return these values as date and time separately, cluttering your dataset).
}
\examples{

data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))

# If you don't need the validation variable, try
data_noval<-read_WEXTOR(path_to_file("BiFiX_data_raw.csv"),
                       keep_validation = FALSE)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utility.R
\name{path_to_file}
\alias{path_to_file}
\title{Get file path to example data file}
\source{
This function is adapted from \code{palmerpenguins} (which is adapted from \code{readxl::readxl_example()}).
}
\usage{
path_to_file(path = NULL)
}
\arguments{
\item{path}{Name of file in quotes with extension;
\code{"BiFiX_data_raw.csv"} will work.
If \code{NULL}, the example file will be listed.}
}
\value{
Gives the path to the example file included in the package. Meant for use in \code{read_WEXTOR()}.
}
\description{
This function makes the example data from the BiFiX study (submitted for publication in BRM) easy to access.
}
\examples{
path_to_file()
path_to_file("BiFiX_data_raw.csv")
head(read.csv(path_to_file("BiFiX_data_raw.csv")))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scale_rextor.R
\name{scale_rextor}
\alias{scale_rextor}
\title{Coloring Scale for Data Visualization}
\usage{
scale_rextor(pal = "cute", direction = 1, aesthetic = "color", ...)
}
\arguments{
\item{pal}{Color palette. Use either numbers from 1 to X or one of the names: \code{'arby'}, \code{'cute'}...}

\item{direction}{Direction of the color palette. Keep blank or use 1 for the default direction or use -1 to reverse the colors.}

\item{aesthetic}{Which aesthetic to use the scale on; either \code{color} or \code{fill}, defaults to \code{color}.}

\item{...}{Other common scale parameters.}
}
\value{
\code{ggplot} plot object
}
\description{
This scale is very versatile and powerful. It offers several color palettes to choose from and automatically recognizes whether to use
a discrete or continuous scale depending on the data type of the mapping object.
It can also be used for both \code{color} and \code{fill} aesthetics by defining \code{aesthetic} accordingly directly inside the function!
}
\examples{
library(ggplot2)
ggplot(iris, aes(Species, Petal.Width, color = Petal.Width)) + 
geom_jitter() + 
theme_wob() + 
scale_rextor()

data <- data.frame(Time = rep(c("Time 1", "Time 2", "Time 3", "Time 4", 
                                "Time 5", "Time 6", "Time 7", "Time 8"), 
                                each = 2),
                                cont = 1:16,
                                Value = c(8, 5, 10, 3, 8, 5, 10, 3,  8, 5, 10, 3,  8, 5, 10, 3))

ggplot(data, aes(x = Time, y = Value, color = Time, fill = Time)) +
  geom_boxplot(alpha = 0.95) +
    theme_wob() +
    scale_rextor(pal = "neon") +
    scale_rextor(pal = "neon", aesthetic = "fill")
    
ggplot(data, aes(x = cont, y = Value, color = cont, fill = cont)) +
  geom_jitter(alpha = 0.8, size = 8) +
  theme_minimal() +
  scale_rextor(pal = "wextor") +
  scale_rextor(pal = "wextor", aesthetic = "fill")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/removepref.R
\name{removepref}
\alias{removepref}
\title{Remove 'WEXTOR' variable name prefixes (automatic)}
\usage{
removepref(dataframe)
}
\arguments{
\item{dataframe}{A dataframe, usefully containing variables that have the server prefix ".wx.#."}
}
\value{
Returns dataframe with those variables renamed that start with the old prefix.
}
\description{
This function strips the old prefix from the server variable names of the dataframe.
It identifies such variables that start with ".wx.#." where # stands for any number, or simply ".wx." and then removes
these prefixes for more easily legible and usable variable names in your data!
}
\examples{
bli <- tibble::tibble(.wx.1.ar = 1:5, y_ar = 6:10, .wx.z = 11:15)
blu <- removepref(bli)
names(bli)
names(blu)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ask_rex.R
\name{ask_rex}
\alias{ask_rex}
\title{Ask Rex}
\usage{
ask_rex(topic = "?")
}
\arguments{
\item{topic}{What you want to know about; either leave it blank for motivation or specify 'ttest', 'mean'... Input must be in quotes!}
}
\value{
Returns advice and explanations on R; sometimes Rex asks follow-up questions
}
\description{
This function lets you ask dino Rex for help.
You can try to ask for specific functions and topics or just use the function as-is
for some motivational words of encouragement. :)
}
\examples{
# Get motivation
ask_rex()

# Get specific information
ask_rex("mean")
ask_rex(topic = "ttest")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme_wob.R
\name{theme_wob}
\alias{theme_wob}
\title{Theme White on Black}
\usage{
theme_wob(max_font_size = 14, contrast = "high")
}
\arguments{
\item{max_font_size}{Maximum font size, used for the plot title (other font sizes are automatically
adjusted accordingly).}

\item{contrast}{Character to indicate the choice of color palette depending on the desired contrast.
Defaults to \code{"high"}. Should be one of \verb{"max", "high", "medium", "low", "pink"} or \code{"rex"}.}
}
\value{
Plot theme.
}
\description{
This theme option is built to be used with a \code{ggplot2} plot.
It offers several options for a dark theme, i.e. dark background with light writing.
}
\examples{
# Load the data
data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))

# Create any plot
library(ggplot2)
ggplot(data, aes(age, color = gender, fill = gender)) + 
  geom_density(alpha = .5) + 
  theme_wob(contrast = "rex")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/namepref.R
\name{namepref0}
\alias{namepref0}
\title{Add variable name prefix (without substitution)}
\usage{
namepref0(dataframe, pref_new)
}
\arguments{
\item{dataframe}{A dataframe}

\item{pref_new}{New prefix character to add to all variable namess in the dataframe have}
}
\value{
Returns dataframe with all variables renamed to start with the new prefix.
}
\description{
This function adds the new prefix and changes the dataframe's names to the new ones.
}
\examples{
bla <- tibble::tibble(x_ar = 1:5, y_ar = 6:10)
blo <- namepref0(bla, "var")
names(bla)
names(blo)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utility.R
\name{check_ok}
\alias{check_ok}
\title{Check whether a plausibility condition is satisfied}
\usage{
check_ok(data, col)
}
\arguments{
\item{data}{A data frame containing plausibility check variables.}

\item{col}{A character string specifying the column name to check for "ok" entries (case-sensitive).}
}
\value{
A logical vector of length \code{nrow(data)}.
}
\description{
Returns a logical vector indicating whether a given check column equals \code{"ok"}.
If the column does not exist in the data, all cases are treated as passing.
}
\details{
Used inside the \code{plausicheck()} function.
}
\examples{
example_df <- data.frame(check_ip = c("ok", "nope", "ok", "OK"))
check_ok(example_df, "check_ip")
}
